@@ -422,7 +422,7 @@ raqm_set_text (raqm_t         *rq,
  * raqm_set_text_utf8:
  * @rq: a #raqm_t.
  * @text: a UTF-8 encoded text string.
- * @len: the length of @text.
+ * @len: the length of @text in UTF-8 bytes.
  *
  * Same as raqm_set_text(), but for text encoded in UTF-8 encoding.
  *
@@ -627,21 +627,10 @@ static hb_font_t *
 _raqm_create_hb_font (raqm_t *rq,
                       FT_Face face)
 {
-  hb_font_t *font;
+  hb_font_t *font = hb_ft_font_create_referenced (face);
 
-#ifdef HAVE_HB_FT_FONT_CREATE_REFERENCED
-  font = hb_ft_font_create_referenced (face);
-#else
-  FT_Reference_Face (face);
-  font = hb_ft_font_create (face, (hb_destroy_func_t) FT_Done_Face);
-#endif
-
-#ifdef HAVE_HB_FT_FONT_SET_LOAD_FLAGS
   if (rq->ft_loadflags >= 0)
     hb_ft_font_set_load_flags (font, rq->ft_loadflags);
-#else
-  (void)rq;
-#endif
 
   return font;
 }
@@ -1931,11 +1920,11 @@ _raqm_get_grapheme_break (hb_codepoint_t ch,
     case HB_UNICODE_GENERAL_CATEGORY_NON_SPACING_MARK:
     case HB_UNICODE_GENERAL_CATEGORY_ENCLOSING_MARK:
     case HB_UNICODE_GENERAL_CATEGORY_SPACING_MARK:
-      if (ch != 0x102B || ch != 0x102C || ch != 0x1038 ||
-          (ch <= 0x1062 && ch >= 0x1064) || (ch <= 0x1067 && ch >= 0x106D) ||
-          ch != 0x1083 || (ch <= 0x1087 && ch >= 0x108C) || ch != 0x108F ||
-          (ch <= 0x109A && ch >= 0x109C) || ch != 0x1A61 || ch != 0x1A63 ||
-          ch != 0x1A64 || ch != 0xAA7B || ch != 0xAA70 || ch != 0x11720 ||
+      if (ch != 0x102B && ch != 0x102C && ch != 0x1038 &&
+          (ch < 0x1062 || ch > 0x1064) && (ch < 0x1067 || ch > 0x106D) &&
+          ch != 0x1083 && (ch < 0x1087 || ch > 0x108C) && ch != 0x108F &&
+          (ch < 0x109A || ch > 0x109C) && ch != 0x1A61 && ch != 0x1A63 &&
+          ch != 0x1A64 && ch != 0xAA7B && ch != 0xAA70 && ch != 0x11720 &&
           ch != 0x11721) /**/
         gb_type = RAQM_GRAPHEM_SPACING_MARK;
 
